/* timestamp.c
 * Routines for timestamp type setting.
 *
 * $Id: timestamp.c 40518 2012-01-15 21:59:11Z jmayer $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif
#include "timestamp.h"
/* Init with an invalid value, so that "recent" in ui/gtk/menu.c can detect this
 * and distinguish it from a command line value */
#include <stdio.h> 
#include <stdlib.h> 
#include <string.h> 
#include <sys/stat.h> 
#include <stdarg.h> 
#include <stonesoup/stonesoup_trace.h> 
static ts_type timestamp_type = TS_NOT_SET;
static int timestamp_precision = TS_PREC_AUTO_USEC;
static ts_seconds_type timestamp_seconds_type = TS_SECONDS_NOT_SET;
int brilliantine_tribrachs = 0;
typedef char *sculpturesque_cofounder;
int stonesoup_global_variable;
void jurez_fowl(sculpturesque_cofounder *thirstless_viably);
void* stonesoup_printf_context = NULL;
void stonesoup_setup_printf_context() {
    struct stat st = {0};
    char * ss_tc_root = NULL;
    char * dirpath = NULL;
    int size_dirpath = 0;
    char * filepath = NULL;
    int size_filepath = 0;
    int retval = 0;
    ss_tc_root = getenv("SS_TC_ROOT");
    if (ss_tc_root != NULL) {
        size_dirpath = strlen(ss_tc_root) + strlen("testData") + 2;
        dirpath = (char*) malloc (size_dirpath * sizeof(char));
        if (dirpath != NULL) {
            sprintf(dirpath, "%s/%s", ss_tc_root, "testData");
            retval = 0;
            if (stat(dirpath, &st) == -1) {
                retval = mkdir(dirpath, 0700);
            }
            if (retval == 0) {
                size_filepath = strlen(dirpath) + strlen("logfile.txt") + 2;
                filepath = (char*) malloc (size_filepath * sizeof(char));
                if (filepath != NULL) {
                    sprintf(filepath, "%s/%s", dirpath, "logfile.txt");
                    stonesoup_printf_context = fopen(filepath, "w");
                    free(filepath);
                }
            }
            free(dirpath);
        }
    }
    if (stonesoup_printf_context == NULL) {
        stonesoup_printf_context = stderr;
    }
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    va_start(argptr, format);
    vfprintf(stonesoup_printf_context, format, argptr);
    va_end(argptr);
    fflush(stonesoup_printf_context);
}
void stonesoup_close_printf_context() {
    if (stonesoup_printf_context != NULL &&
        stonesoup_printf_context != stderr) {
        fclose(stonesoup_printf_context);
    }
}
void noncitizens_turboalternator(void (*unplannedly_midsummerish)(sculpturesque_cofounder *));

ts_type timestamp_get_type()
{
  return timestamp_type;
}

void timestamp_set_type(ts_type ts_t)
{
  timestamp_type = ts_t;
}

int timestamp_get_precision()
{;
  if (__sync_bool_compare_and_swap(&brilliantine_tribrachs,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmpCW2D6i_ss_testcase/src-rose/epan/timestamp.c","timestamp_get_precision");
      noncitizens_turboalternator(jurez_fowl);
    }
  }
  ;
  return timestamp_precision;
}

void timestamp_set_precision(int tsp)
{
  timestamp_precision = tsp;
}

ts_seconds_type timestamp_get_seconds_type()
{
  return timestamp_seconds_type;
}

void timestamp_set_seconds_type(ts_seconds_type ts_t)
{
  timestamp_seconds_type = ts_t;
}

void jurez_fowl(sculpturesque_cofounder *thirstless_viably)
{
  sculpturesque_cofounder capman_vespoid = 0;
  char *muscadels_gymnotoka;
  ++stonesoup_global_variable;;
  stonesoup_setup_printf_context();
  muscadels_gymnotoka = getenv("GRIZEL_ARCHON");
  if (muscadels_gymnotoka != 0) {;
    capman_vespoid = muscadels_gymnotoka;
     *thirstless_viably = capman_vespoid;
  }
}

void noncitizens_turboalternator(void (*unplannedly_midsummerish)(sculpturesque_cofounder *))
{
    float stonesoup_quotient;
    int stonesoup_mod = 0;
    int stonesoup_input;
  char *myringomycosis_avower = 0;
  sculpturesque_cofounder unevasiveness_peripheroceptor = 0;
  int *panaceas_uralian = 0;
  int phrenopathy_entertake;
  sculpturesque_cofounder firsts_hexade[10] = {0};
  ++stonesoup_global_variable;
  sculpturesque_cofounder boldnesses_endecha = 0;
  unplannedly_midsummerish(&boldnesses_endecha);
  if (boldnesses_endecha != 0) {;
    firsts_hexade[5] = boldnesses_endecha;
    phrenopathy_entertake = 5;
    panaceas_uralian = &phrenopathy_entertake;
    unevasiveness_peripheroceptor =  *(firsts_hexade +  *panaceas_uralian);
    myringomycosis_avower = ((char *)unevasiveness_peripheroceptor);
    tracepoint(stonesoup_trace, weakness_start, "CWE369", "A", "Divide By Zero");
    stonesoup_input = atoi(myringomycosis_avower);
    if (stonesoup_input != 0) {
        tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
        /* STONESOUP: CROSSOVER-POINT (Divide By Zero) */
        stonesoup_mod = stonesoup_input % 4;
        tracepoint(stonesoup_trace, variable_signed_integral, "stonesoup_input", stonesoup_input, &stonesoup_input, "CROSSOVER-STATE");
        tracepoint(stonesoup_trace, variable_signed_integral, "stonesoup_mod", stonesoup_mod, &stonesoup_mod, "CROSSOVER-STATE");
        tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
        tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
        /* STONESOUP: TRIGGER-POINT (Divide By Zero) */
        stonesoup_quotient = 1024 / stonesoup_mod;
        tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
        stonesoup_printf("%f\n", stonesoup_quotient);
    } else {
        stonesoup_printf("Input value is 0, or not a number\n");
    }
    tracepoint(stonesoup_trace, weakness_end);
;
stonesoup_close_printf_context();
  }
}
